@@ -2,13 +2,12 @@
 # -*- coding: utf-8 -*-
 
 from requests import Response
-import response_wrapper
-from util import set_var,get_var
-import json # eval 可能会用到
-import re
+from HttpBoot.response_wrapper import ResponseWrap
+from pyutilb.util import *
+from pyutilb import log
 
 # 抽取器
-class Extractor(response_wrapper.ResponseWrap):
+class Extractor(ResponseWrap):
 
     def __init__(self, res: Response = None):
         super(Extractor, self).__init__(res)
@@ -43,14 +42,14 @@ class Extractor(response_wrapper.ResponseWrap):
             val = self._get_val_by(type, path)
             # 抽取单个字段
             set_var(var, val)
-            print(f"从响应中抽取参数: {var}={val}")
+            log.debug(f"从响应中抽取参数: {var}={val}")
 
     # 执行eval类型的抽取
     def run_eval(self, fields):
         for var, expr in fields.items():
             # 获得字段值
-            val = eval(expr, globals(), util.vars) # 丢失本地与全局变量, 如引用不了json模块
+            val = eval(expr, globals(), bvars) # 丢失本地与全局变量, 如引用不了json模块
             # 抽取单个字段
             set_var(var, val)
-            print(f"抽取参数: {var}={val}")
+            log.debug(f"抽取参数: {var}={val}")
 
